summaryrefslogtreecommitdiff
path: root/src/being.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/being.h')
-rw-r--r--src/being.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/being.h b/src/being.h
index 9213a2dc..6e90b39d 100644
--- a/src/being.h
+++ b/src/being.h
@@ -149,7 +149,6 @@ class Being : public Sprite, public ConfigListener
enum { DOWN = 1, LEFT = 2, UP = 4, RIGHT = 8 };
#ifdef EATHENA_SUPPORT
- Uint16 mX, mY; /**< Tile coordinates */
int mFrame;
int mWalkTime;
#endif
@@ -184,30 +183,30 @@ class Being : public Sprite, public ConfigListener
virtual void setDestination(Uint16 destX, Uint16 destY);
#else
/**
* Returns the path to the being's current destination
*/
- virtual Path findPath();
+ void setDestination(int ex, int ey);
/**
- * Creates a path for the being from sx,sy to ex,ey
+ * Returns the destination for this being.
*/
- void setDestination(int sx, int sy, int ex, int ey);
+ const Vector &getDestination() const { return mDest; }
+#endif
/**
- * Creates a path for the being from current position to ex and ey
+ * Returns the tile x or y coord
*/
- void setDestination(int ex, int ey);
+ int getTileX() const
+ { return mX; }
- /**
- * Adjusts course to expected start point.
- */
- void adjustCourse(int srcX, int srcY);
+ int getTileY() const
+ { return mY; }
/**
- * Returns the destination for this being.
+ * Sets the tile x or y coord
*/
- const Vector &getDestination() const { return mDest; }
-#endif
+ void setTileCoords(int x, int y)
+ { mX = x; mY = y; }
/**
* Puts a "speech balloon" above this being for the specified amount
@@ -603,6 +602,7 @@ class Being : public Sprite, public ConfigListener
Vector mPos;
Vector mDest;
int mPx, mPy; /**< Position in pixels */
+ int mX, mY; /**< Position on tile */
/** Target cursor being used */
SimpleAnimation* mUsedTargetCursor;
@@ -184,30 +183,30 @@ class Being : public Sprite, public ConfigListener
#else
/**
- * Returns the path to the being's current destination
+ * Creates a path for the being from current position to ex and ey
*/